pub struct BidderId(pub Uuid);Expand description
Unique identifier for a bidder in the flow trading system
Tuple Fields
0: UuidTrait Implementations
Sourceimpl<'r> Decode<'r, Sqlite> for BidderId
impl<'r> Decode<'r, Sqlite> for BidderId
Sourcefn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
fn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
Decode a new value of this type using a raw value from the database.
Sourceimpl<'de> Deserialize<'de> for BidderId
impl<'de> Deserialize<'de> for BidderId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'q> Encode<'q, Sqlite> for BidderId
impl<'q> Encode<'q, Sqlite> for BidderId
Sourcefn encode_by_ref(
&self,
args: &mut Vec<SqliteArgumentValue<'q>>,
) -> Result<IsNull, BoxDynError>
fn encode_by_ref( &self, args: &mut Vec<SqliteArgumentValue<'q>>, ) -> Result<IsNull, BoxDynError>
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
Sourceimpl Ord for BidderId
impl Ord for BidderId
Sourceimpl PartialOrd for BidderId
impl PartialOrd for BidderId
impl Copy for BidderId
impl Eq for BidderId
impl StructuralPartialEq for BidderId